package ODS::Table::Column::Email;

extends 'ODS::Table::Column::Base';

#sub validation { return $_[1]; }

#sub inflation { return $_[1]; }

#sub deflation { return $_[1]; }

#sub coercion { return $_[1]; }

1;

__END__
